@@ -121,9 +121,14 @@ protected:
 	{
 		IONotifier *		fKeySwitchNotifier;
 		UInt8				fANSIVersion;
+		UInt32				fReadTimeoutDuration;
+		UInt32				fWriteTimeoutDuration;
 	};
 	IOSCSIPrimaryCommandsDeviceExpansionData * fIOSCSIPrimaryCommandsDeviceReserved;
 	
+	#define	fReadTimeoutDuration	fIOSCSIPrimaryCommandsDeviceReserved->fReadTimeoutDuration
+	#define	fWriteTimeoutDuration	fIOSCSIPrimaryCommandsDeviceReserved->fWriteTimeoutDuration
+	
 	UInt8							fDefaultInquiryCount;
 	OSDictionary *					fDeviceCharacteristicsDictionary;
 	UInt32							fNumCommandsOutstanding;
